Reference Guide — PyQt-builder v1.14.1 Documentation

# Reference Guide

- Introduction
  - Installation
- Command Line Tools
- `pyproject.toml` Reference
  - `[tool.sip.builder]` Section
  - `[tool.sip.project]` Section
  - Bindings Sections
- `pyqtbuild` Module Reference
  - `PYQTBUILD_VERSION`
  - `PYQTBUILD_VERSION_STR`
  - `PyQtBindings`
  - `PyQtProject`
  - `QmakeBuilder`
  - `QmakeTargetInstallable`
- An Example
- Bundling Qt Using pyqt-bundle
  - Bundling Qt6 Additional Libraries